from datasets import load_dataset
from transformers import AutoTokenizer
from transformers import TFAutoModelForSequenceClassification
import numpy as np

# load data set
# dataset = load_dataset("glue", "cola")
dataset = load_dataset("imdb")

train = dataset["train"].shuffle(seed=42).select(range(100))

# tokenize the sentences
tokenizer = AutoTokenizer.from_pretrained("bert-base-cased")

x_train = dict(tokenizer(train["text"], 
  return_tensors="np", 
  padding='max_length', 
  truncation=True))

# convert the sentences in a numpy array
y_train = np.array(train["label"])  # Label is already an array of 0 and 1

# load pre-trained model
model = TFAutoModelForSequenceClassification.from_pretrained("bert-base-cased")
model.bert.trainable = False
model.summary()

# do usual model stuff
model.compile(optimizer="adam", metrics=["accuracy"], loss="binary_crossentropy")

model.fit(x_train, y_train, epochs=5, batch_size=1)

print("Training done.")

test = dataset["test"].shuffle(seed=42).select(range(100))
x_test = dict(tokenizer(test["text"], 
  return_tensors="np", 
  padding='max_length', 
  truncation=True))
y_test = np.array(test["label"])

print(model.evaluate(x_test, y_test))
